Index: uspace/app/nettest1/nettest1.c
===================================================================
--- uspace/app/nettest1/nettest1.c	(revision d4d74dc3a5ed0e53be6d43c318f9f3798e9f4c49)
+++ uspace/app/nettest1/nettest1.c	(revision 287d729f794bf828f2721da0c621cd40924d377d)
@@ -46,4 +46,5 @@
 #include <arg_parse.h>
 
+#include <inet/dnsr.h>
 #include <net/in.h>
 #include <net/in6.h>
@@ -75,5 +76,5 @@
 	printf(
 	    "Network Networking test 1 aplication - sockets\n"
-	    "Usage: echo [options] numeric_address\n"
+	    "Usage: nettest1 [options] host\n"
 	    "Where options are:\n"
 	    "-f protocol_family | --family=protocol_family\n"
@@ -290,4 +291,5 @@
 	struct sockaddr_in address_in;
 	struct sockaddr_in6 address_in6;
+	dnsr_hostinfo_t *hinfo;
 	uint8_t *address_start;
 
@@ -319,7 +321,7 @@
 	}
 
 	/* If not before the last argument containing the address */
 	if (index >= argc) {
-		printf("Command line error: missing address\n");
+		printf("Command line error: missing host name\n");
 		nettest1_print_help();
 		return EINVAL;
@@ -348,9 +350,22 @@
 	}
 
 	/* Parse the last argument which should contain the address */
 	rc = inet_pton(family, argv[argc - 1], address_start);
 	if (rc != EOK) {
-		fprintf(stderr, "Address parse error %d\n", rc);
-		return rc;
+		/* Try interpreting as a host name */
+		rc = dnsr_init();
+		if (rc != EOK) {
+			printf("Failed connecting DNS resolution "
+			    "service (%d).\n", rc);
+			return rc;
+		}
+
+		rc = dnsr_name2host(argv[argc - 1], &hinfo);
+		if (rc != EOK) {
+			printf("Error resolving host '%s'.\n", argv[argc - 1]);
+			return rc;
+		}
+
+		address_in.sin_addr.s_addr = host2uint32_t_be(hinfo->addr.ipv4);
 	}
 
@@ -319,7 +321,7 @@
 	}
 
-	/* If not before the last argument containing the address */
+	/* If not before the last argument containing the host */
 	if (index >= argc) {
@@ -348,9 +350,22 @@
 	}
 
-	/* Parse the last argument which should contain the address */
+	/* Parse the last argument which should contain the host/address */
 	rc = inet_pton(family, argv[argc - 1], address_start);
 	if (rc != EOK) {
